@@ -10,10 +10,10 @@ export const NextRunLabel = ({ vm }) => {
   if (!vm.get('nextRunExists')) {
     return null
   }
-
+  const idPrefix = `${vm.get('name')}-nextrun`
   return (<div className={style['vm-flag-container']}>
     <FieldHelp content={msg.vmHasPendingConfigurationChanges()}>
-      <span className={'label label-info ' + style['vm-flag']}>{msg.pendingChanges()}</span>
+      <span className={'label label-info ' + style['vm-flag']} id={`${idPrefix}-changes`}>{msg.pendingChanges()}</span>
     </FieldHelp>
   </div>)
 }
